@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: client.c,v 1.70 2007/10/18 21:51:43 evertonm Exp $ */
+/* $Id: client.c,v 1.71 2008/03/27 20:57:19 evertonm Exp $ */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -461,6 +461,7 @@ static int greet(int sd)
   opt.write_floor             = nepim_global.server_write_floor;
   opt.write_ceil              = nepim_global.server_write_ceil;
   opt.report_partial_min_max  = nepim_global.report_partial_min_max;
+  opt.mss                     = nepim_global.server_tcp_mss;
 
   if (nepim_global.password) {
     opt.password_buf      = (char *) nepim_global.password;
@@ -936,7 +937,8 @@ static void spawn_one_tcp_client(const char *hostport,
                                      nepim_global.win_send,
 				     nodelay,
 				     nepim_global.tos,
-				     nepim_global.socket_keepalive);
+				     nepim_global.socket_keepalive,
+				     nepim_global.client_tcp_mss);
     if (sd < 0) {
       if (ai->ai_family == AF_UNIX)
 	fprintf(stderr, 
