@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: usock.c,v 1.10 2006/03/29 21:23:14 evertonm Exp $ */
+/* $Id: usock.c,v 1.11 2006/06/02 01:24:51 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -46,7 +46,8 @@ void nepim_usock_set_add(nepim_usock_set_t *set, int index)
   us->writers = 0;
   us->write_soft_errors = 0;
   us->read_soft_errors = 0;
-  us->good_writes = 0;
+  us->good_writes_full = 0;
+  us->good_writes_partial = 0;
   us->good_reads = 0;
 
   nepim_array_add(&set->array, index, us);
@@ -122,9 +123,10 @@ void nepim_usock_write_error(nepim_usock_set_t *set, int index,
   
   if (verbose)
     fprintf(stderr, 
-	    "%d %d-%d: sendto: write_soft_errors=%d good_writes=%d errno=%d: %s\n", 
+	    "%d %d-%d: sendto: wr_soft_errors=%d wr_ok_full=%d wr_ok_partial=%d errno=%d: %s\n", 
 	    index, local_slot, remote_slot,
-	    us->write_soft_errors, us->good_writes,
+	    us->write_soft_errors,
+	    us->good_writes_full, us->good_writes_partial,
 	    err_no, strerror(err_no));
 }
 
@@ -144,13 +146,22 @@ void nepim_usock_read_error(nepim_usock_set_t *set, int index,
 	    err_no, strerror(err_no));
 }
 
-void nepim_usock_write_good(nepim_usock_set_t *set, int index)
+void nepim_usock_write_good_full(nepim_usock_set_t *set, int index)
 {
   nepim_usock_t *us = nepim_usock_set_get(set, index);
   assert(us);
-  assert(us->good_writes >= 0);
+  assert(us->good_writes_full >= 0);
   
-  ++us->good_writes;
+  ++us->good_writes_full;
+}
+
+void nepim_usock_write_good_partial(nepim_usock_set_t *set, int index)
+{
+  nepim_usock_t *us = nepim_usock_set_get(set, index);
+  assert(us);
+  assert(us->good_writes_partial >= 0);
+  
+  ++us->good_writes_partial;
 }
 
 void nepim_usock_read_good(nepim_usock_set_t *set, int index)
